@@ -3,7 +3,7 @@ use 5.22.0;
 no strict; no warnings; no diagnostics;
 use common::sense;
 
-our $VERSION = "0.2.1";
+our $VERSION = "0.2.2";
 
 use Exporter qw/import/;
 use Scalar::Util   qw//;
@@ -705,7 +705,7 @@ sub from_inc(;$) {
 		return $path if -f $path;
 	}
 
-	undef
+	return;
 }
 
 # Из файлового пути в @INC в пакет
@@ -715,8 +715,8 @@ sub to_inc(;$) {
 	my $inc = join "|", map quotemeta, @INC;
 	
 	return to_pkg $' if $path =~ m!^(?:$inc)/!;
-	
-	undef
+
+	return;
 }
 
 # Подключает модуль, если он ещё не подключён, и возвращает его
@@ -741,7 +741,7 @@ Aion::Fs - utilities for the file system: reading, writing, searching, replacing
 
 =head1 VERSION
 
-0.2.1
+0.2.2
 
 =head1 SYNOPSIS
 
@@ -1629,7 +1629,7 @@ Translates the path from the FS to the package. Without a parameter, uses C<$_>.
 Translates the packet to the FS path in C<@INC>. The package file must exist in one of the C<@INC> paths. Without a parameter, uses C<$_>.
 
 	from_inc "Aion::Fs" # -> $INC{'Aion/Fs.pm'}
-	[map from_inc, "Aion::Fs"]  # --> [$INC{'Aion/Fs.pm'}]
+	[map from_inc, "A::B::C", "Aion::Fs"]  # --> [$INC{'Aion/Fs.pm'}]
 	
 	from_inc "A::B::C" # -> undef
 
@@ -1638,7 +1638,7 @@ Translates the packet to the FS path in C<@INC>. The package file must exist in
 Translates the path from FS to C<@INC> into a package. Without a parameter, uses C<$_>.
 
 	to_inc $INC{'Aion/Fs.pm'} # => Aion::Fs
-	[map to_inc, $INC{'Aion/Fs.pm'}]  # --> ["Aion::Fs"]
+	[map to_inc,"A/B/C.pm", $INC{'Aion/Fs.pm'}]  # --> ["Aion::Fs"]
 	
 	to_inc 'Aion/Fs.pm' # -> undef
 
